@@ -16,6 +16,7 @@ from typing import (
     Dict,
     Any,
     NamedTuple,
+    TYPE_CHECKING,
 )
 
 from rasa import telemetry
@@ -34,6 +35,7 @@ from rasa.nlu.constants import (
     ENTITY_ATTRIBUTE_CONFIDENCE_TYPE,
     ENTITY_ATTRIBUTE_CONFIDENCE_ROLE,
     ENTITY_ATTRIBUTE_CONFIDENCE_GROUP,
+    ENTITY_ATTRIBUTE_TEXT,
 )
 from rasa.shared.nlu.constants import (
     TEXT,
@@ -58,6 +60,17 @@ from rasa.nlu.tokenizers.tokenizer import Token
 from rasa.utils.tensorflow.constants import ENTITY_RECOGNITION
 from rasa.shared.importers.importer import TrainingDataImporter
 
+if TYPE_CHECKING:
+    from typing_extensions import TypedDict
+
+    EntityPrediction = TypedDict(
+        "EntityPrediction",
+        {
+            ENTITY_ATTRIBUTE_TEXT: Text,
+            "entities": List[Dict[Text, Any]],
+            "predicted_entities": List[Dict[Text, Any]],
+        },
+    )
 logger = logging.getLogger(__name__)
 
 # Exclude 'EntitySynonymMapper' and 'ResponseSelector' as their super class
@@ -166,17 +179,10 @@ def drop_intents_below_freq(
     logger.debug(
         "Raw data intent examples: {}".format(len(training_data.intent_examples))
     )
-    keep_examples = [
-        ex
-        for ex in training_data.intent_examples
-        if training_data.number_of_examples_per_intent[ex.get(INTENT)] >= cutoff
-    ]
 
-    return TrainingData(
-        keep_examples,
-        training_data.entity_synonyms,
-        training_data.regex_features,
-        responses=training_data.responses,
+    examples_per_intent = training_data.number_of_examples_per_intent
+    return training_data.filter_training_examples(
+        lambda ex: examples_per_intent.get(ex.get(INTENT), 0) >= cutoff
     )
 
 
@@ -645,7 +651,7 @@ def _calculate_report(
     report_as_dict: Optional[bool] = None,
     exclude_label: Optional[Text] = None,
 ) -> Tuple[Union[Text, Dict], float, float, float, np.ndarray, List[Text]]:
-    from rasa.test import get_evaluation_metrics
+    from rasa.model_testing import get_evaluation_metrics
     import sklearn.metrics
     import sklearn.utils.multiclass
 
@@ -737,7 +743,7 @@ def collect_incorrect_entity_predictions(
     entity_results: List[EntityEvaluationResult],
     merged_predictions: List[Text],
     merged_targets: List[Text],
-):
+) -> List["EntityPrediction"]:
     """Get incorrect entity predictions.
 
     Args:
@@ -796,7 +802,7 @@ def collect_successful_entity_predictions(
     entity_results: List[EntityEvaluationResult],
     merged_predictions: List[Text],
     merged_targets: List[Text],
-):
+) -> List["EntityPrediction"]:
     """Get correct entity predictions.
 
     Args:
@@ -1350,14 +1356,12 @@ def get_entity_extractors(interpreter: Interpreter) -> Set[Text]:
 
 def is_entity_extractor_present(interpreter: Interpreter) -> bool:
     """Checks whether entity extractor is present."""
-
     extractors = get_entity_extractors(interpreter)
-    return extractors != []
+    return len(extractors) > 0
 
 
 def is_intent_classifier_present(interpreter: Interpreter) -> bool:
     """Checks whether intent classifier is present."""
-
     from rasa.nlu.classifiers.classifier import IntentClassifier
 
     intent_classifiers = [
@@ -1843,7 +1847,7 @@ async def compare_nlu(
     Returns: training examples per run
     """
 
-    from rasa.train import train_nlu_async
+    from rasa.model_training import train_nlu_async
 
     training_examples_per_run = []
 
@@ -1930,7 +1934,7 @@ def _compute_metrics(
 
     Returns: metrics
     """
-    from rasa.test import get_evaluation_metrics
+    from rasa.model_testing import get_evaluation_metrics
 
     # compute fold metrics
     targets, predictions = _targets_predictions_from(
@@ -1952,7 +1956,7 @@ def _compute_entity_metrics(
 
     Returns: entity metrics
     """
-    from rasa.test import get_evaluation_metrics
+    from rasa.model_testing import get_evaluation_metrics
 
     entity_metric_results: EntityMetrics = defaultdict(lambda: defaultdict(list))
     extractors = get_entity_extractors(interpreter)
