@@ -82,16 +82,16 @@ class StoryReader:
         """
         raise NotImplementedError
 
-    def _add_current_stories_to_result(self):
+    def _add_current_stories_to_result(self) -> None:
         if self.current_step_builder:
             self.current_step_builder.flush()
             self.story_steps.extend(self.current_step_builder.story_steps)
 
-    def _new_story_part(self, name: Text, source_name: Optional[Text]):
+    def _new_story_part(self, name: Text, source_name: Optional[Text]) -> None:
         self._add_current_stories_to_result()
         self.current_step_builder = StoryStepBuilder(name, source_name)
 
-    def _new_rule_part(self, name: Text, source_name: Optional[Text]):
+    def _new_rule_part(self, name: Text, source_name: Optional[Text]) -> None:
         self._add_current_stories_to_result()
         self.current_step_builder = StoryStepBuilder(name, source_name, is_rule=True)
 
@@ -154,6 +154,6 @@ def _map_legacy_event_names(event: Event) -> None:
 class StoryParseError(RasaCoreException, ValueError):
     """Raised if there is an error while parsing a story file."""
 
-    def __init__(self, message) -> None:
+    def __init__(self, message: Text) -> None:
         self.message = message
         super(StoryParseError, self).__init__()
