@@ -4,9 +4,19 @@ import os
 import shutil
 import warnings
 from types import TracebackType
-from typing import Any, Coroutine, Dict, List, Optional, Text, Type, TypeVar, Union
+from typing import (
+    Any,
+    Coroutine,
+    Dict,
+    List,
+    Optional,
+    Text,
+    Type,
+    TypeVar,
+    Union,
+    NoReturn,
+)
 
-import rasa.core.utils
 import rasa.utils.io
 from rasa.constants import DEFAULT_LOG_LEVEL_LIBRARIES, ENV_LOG_LEVEL_LIBRARIES
 from rasa.shared.constants import DEFAULT_LOG_LEVEL, ENV_LOG_LEVEL
@@ -52,7 +62,7 @@ def read_global_config(path: Text) -> Dict[Text, Any]:
         return {}
 
 
-def set_log_level(log_level: Optional[int] = None):
+def set_log_level(log_level: Optional[int] = None) -> None:
     """Set log level of Rasa and Tensorflow either to the provided log level or
     to the log level specified in the environment variable 'LOG_LEVEL'. If none is set
     a default log level will be used."""
@@ -104,24 +114,16 @@ def update_tensorflow_log_level() -> None:
     # first import since some warnings are raised on the first import.
     os.environ["TF_CPP_MIN_LOG_LEVEL"] = "2"
 
-    import tensorflow as tf
-
     log_level = os.environ.get(ENV_LOG_LEVEL_LIBRARIES, DEFAULT_LOG_LEVEL_LIBRARIES)
 
-    if log_level == "DEBUG":
-        tf_log_level = tf.compat.v1.logging.DEBUG
-    elif log_level == "INFO":
-        tf_log_level = tf.compat.v1.logging.INFO
-    elif log_level == "WARNING":
-        tf_log_level = tf.compat.v1.logging.WARN
-    else:
-        tf_log_level = tf.compat.v1.logging.ERROR
+    if not log_level:
+        log_level = "ERROR"
 
-    tf.compat.v1.logging.set_verbosity(tf_log_level)
+    logging.getLogger("tensorflow").setLevel(log_level)
     logging.getLogger("tensorflow").propagate = False
 
 
-def update_sanic_log_level(log_file: Optional[Text] = None):
+def update_sanic_log_level(log_file: Optional[Text] = None) -> None:
     """Set the log level of sanic loggers to the log level specified in the environment
     variable 'LOG_LEVEL_LIBRARIES'."""
     from sanic.log import logger, error_logger, access_logger
@@ -221,7 +223,7 @@ def write_global_config_value(name: Text, value: Any) -> bool:
 def read_global_config_value(name: Text, unavailable_ok: bool = True) -> Any:
     """Read a value from the global Rasa configuration."""
 
-    def not_found():
+    def not_found() -> None:
         if unavailable_ok:
             return None
         else:
@@ -262,7 +264,8 @@ class RepeatedLogFilter(logging.Filter):
 
     last_log = None
 
-    def filter(self, record):
+    def filter(self, record: logging.LogRecord) -> bool:
+        """Determines whether current log is different to last log."""
         current_log = (
             record.levelno,
             record.pathname,
