@@ -71,7 +71,7 @@ class RasaModel(TmpKerasModel):
     Cannot be used as tf.keras.Model.
     """
 
-    def __init__(self, random_seed: Optional[int] = None, **kwargs,) -> None:
+    def __init__(self, random_seed: Optional[int] = None, **kwargs: Any) -> None:
         """Initialize the RasaModel.
 
         Args:
@@ -92,7 +92,7 @@ class RasaModel(TmpKerasModel):
         self._tf_predict_step = None
         self.prepared_for_prediction = False
 
-    def _set_random_seed(self):
+    def _set_random_seed(self) -> None:
         random.seed(self.random_seed)
         tf.random.set_seed(self.random_seed)
         np.random.seed(self.random_seed)
@@ -293,8 +293,8 @@ class RasaModel(TmpKerasModel):
         model_data_example: RasaModelData,
         predict_data_example: Optional[RasaModelData] = None,
         finetune_mode: bool = False,
-        *args,
-        **kwargs,
+        *args: Any,
+        **kwargs: Any,
     ) -> "RasaModel":
         """Loads a model from the given weights.
 
@@ -378,14 +378,15 @@ class RasaModel(TmpKerasModel):
         feature_dimension: int,
         idx: int,
         number_of_dimensions: int,
-    ):
+    ) -> Tuple[tf.Tensor, int]:
         if isinstance(batch[idx], tf.Tensor):
             # explicitly substitute last dimension in shape with known
             # static value
             if number_of_dimensions > 1 and (
                 batch[idx].shape is None or batch[idx].shape[-1] is None
             ):
-                shape = [None] * (number_of_dimensions - 1) + [feature_dimension]
+                shape: List[Optional[int]] = [None] * (number_of_dimensions - 1)
+                shape.append(feature_dimension)
                 batch[idx].set_shape(shape)
 
             return batch[idx], idx + 1
@@ -402,7 +403,7 @@ class RasaModel(TmpKerasModel):
         feature_dimension: int,
         idx: int,
         number_of_dimensions: int,
-    ):
+    ) -> Tuple[tf.SparseTensor, int]:
         # explicitly substitute last dimension in shape with known
         # static value
         shape = [batch[idx + 2][i] for i in range(number_of_dimensions - 1)] + [
@@ -499,7 +500,7 @@ class TransformerRasaModel(RasaModel):
         drop_rate_attention: float,
         unidirectional: bool,
         prefix: Text = "transformer",
-    ):
+    ) -> None:
         if num_layers > 0:
             self._tf_layers[f"{prefix}.{name}"] = TransformerEncoder(
                 num_layers,
@@ -715,7 +716,7 @@ class TransformerRasaModel(RasaModel):
         sentence_x: tf.Tensor,
         name: Text,
         mask_text: tf.Tensor,
-    ):
+    ) -> tf.Tensor:
         if sequence_x.shape[-1] != sentence_x.shape[-1]:
             sequence_x = self._tf_layers[f"concat_layer.{name}_{SEQUENCE}"](
                 sequence_x, self._training
